@@ -2,7 +2,8 @@
 
 .onLoad <- function(libname, pkgname) {
   options(
-    bigstatsr.ncores.max = parallel::detectCores()
+    bigstatsr.ncores.max          = parallel::detectCores(),
+    bigstatsr.check.parallel.blas = TRUE
   )
 }
 
@@ -10,7 +11,9 @@
 
 .onUnload <- function(libpath) {
   options(
-    bigstatsr.ncores.max = NULL
+    bigstatsr.ncores.max          = NULL,
+    bigstatsr.check.parallel.blas = NULL,
+    default.nproc.blas            = NULL
   )
 }
 
